package com.ruoyi.rocketmq.service;

import com.ruoyi.rocketmq.domain.InitialMountPointInfo;
import org.springframework.data.repository.query.Param;

import java.util.List;
import java.util.Map;

/**
 * 挂载点监控信息Service接口
 * 
 * @author gyt
 * @date 2025-08-25
 */
public interface IInitialMountPointInfoService 
{
    /**
     * 查询挂载点监控信息
     * 
     * @param id 挂载点监控信息主键
     * @return 挂载点监控信息
     */
    public InitialMountPointInfo selectInitialMountPointInfoById(Long id);

    /**
     * 查询挂载点监控信息列表
     * 
     * @param initialMountPointInfo 挂载点监控信息
     * @return 挂载点监控信息集合
     */
    public List<InitialMountPointInfo> selectInitialMountPointInfoList(InitialMountPointInfo initialMountPointInfo);

    /**
     * 新增挂载点监控信息
     * 
     * @param initialMountPointInfo 挂载点监控信息
     * @return 结果
     */
    public int insertInitialMountPointInfo(InitialMountPointInfo initialMountPointInfo);

    /**
     * 修改挂载点监控信息
     * 
     * @param initialMountPointInfo 挂载点监控信息
     * @return 结果
     */
    public int updateInitialMountPointInfo(InitialMountPointInfo initialMountPointInfo);

    /**
     * 批量删除挂载点监控信息
     * 
     * @param ids 需要删除的挂载点监控信息主键集合
     * @return 结果
     */
    public int deleteInitialMountPointInfoByIds(Long[] ids);

    /**
     * 删除挂载点监控信息信息
     * 
     * @param id 挂载点监控信息主键
     * @return 结果
     */
    public int deleteInitialMountPointInfoById(Long id);
    /**
     * 批量新增挂载点监控信息
     *
     * @param list 挂载点监控信息集合
     * @return 结果
     */
    public int batchInsertInitialMountPointInfo(@Param("list") List<InitialMountPointInfo> list);
    /**
     * 获取挂载点监控信息详细信息
     */
    InitialMountPointInfo pointDetailsMsg(InitialMountPointInfo initialMountPointInfo);
    /**
     * 获取挂载点监控信息的空间图形
     */
    Map<String, Object> spaceEcharts(InitialMountPointInfo initialMountPointInfo);

    /**
     * 获取挂载文件/的空间利用率
     * @param initialMountPointInfo
     * @return
     */
    Map<String, Object> spaceRateEcharts(InitialMountPointInfo initialMountPointInfo);

    /**
     * 获取指定服务器的挂载文件系统名
     * @param initialMountPointInfo
     * @return
     */
    List<Map> getAllMountName(InitialMountPointInfo initialMountPointInfo);
}
